import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { InAppBrowser } from '@ionic-native/in-app-browser/ngx';
import { BackendlessService } from 'src/app/services/backendless.service';
import { AlertService } from 'src/app/services/alert.service';

@Component({
  selector: 'app-llista-elements',
  templateUrl: './llista-elements.component.html',
  styleUrls: ['./llista-elements.component.scss'],
})
export class LlistaElementsComponent implements OnInit {

  @Input() listItems: any[] = [];
  @Input() tipus: string = '';
  @Output() modificaClick: EventEmitter<any> = new EventEmitter<any>();

  constructor(private iab:InAppBrowser, private backendless:BackendlessService, private alertService:AlertService) { 
    console.log("llista elements constructor");    
  }

  ngOnInit() {
    console.log("Tipus: "+this.tipus);   
    console.log("ListItems: "+this.listItems);
  }

  onClick(url:string){
    this.iab.create(url,'_blank');
  }

  fetch(taula:string){
    console.log("Llista-elements component -- Fetching elements from " + taula);
    this.backendless.fetch(taula)
        .then(response =>{          
          this.listItems=response;
        })
        .catch(responseError=>{          
          this.alertService.handleError(responseError);
        });
    
  }

  esborrar(element:any){
    console.log(element);
    this.alertService.showAlert({
      header: "Segur?",
      message: "Segur que vols eliminar-ho?",
      buttons:[{text:'Sí', role:'ok', 
      handler:()=> this.backendless.delete(element.objectId, this.tipus)
                      .then(response=>{ this.fetch(this.tipus) })
                      .catch(error=>{
                          this.alertService.handleError(error);
                      })
              },{text:'No', role:'cancel'}]
      }).then(missatge=> missatge.present());
  } 

}
