import { Component, OnInit } from '@angular/core';
import { UsersService } from 'src/app/services/users.service';
import { AlertService } from 'src/app/services/alert.service';
import { Router } from '@angular/router';
import { timer } from "rxjs";
@Component({
  selector: 'app-login',
  templateUrl: './login.page.html',
  styleUrls: ['./login.page.scss'],
})
export class LoginPage implements OnInit {
  //Només es veu el carregant quan accedim a l'app.
  showSplash = !this.router.navigated; 
  campEmail = "";
  constructor(private usersService:UsersService, private alertService:AlertService, private router:Router) {
    console.log("RouterState Home: "+this.router.navigated);    
    //Custom ionic splash + animation - https://www.youtube.com/watch?v=dPUmskG_-y0
    if(this.showSplash){
      timer(3000).subscribe(()=> this.showSplash=false);
    }

    this.usersService.isValidLogin()
        .then(res =>{if(res) {this.goToHome()}})
        .catch(err => this.alertService.handleError(err));
  }

  ngOnInit() {
  }

  private goToHome(){
    this.router.navigateByUrl("home")
  }

  login(data:any){
    this.usersService.login(data.form.value.email,data.form.value.password)
        .then(() => this.goToHome())
        .catch(error => this.alertService.showToast(error.message));
  }

  loginFacebook(){ 

    //no és lo seu usar login de facebook per privacitat
    //https://simplelogin.io/blog/do-not-use-facebook-sdk/
    let mapeig = {'email':'email','first_name':'name','last_name':'llinatge1'};
    //let mapeig = {'email':'email'};
    this.usersService.loginFacebook(mapeig)
      .then(()=>this.goToHome())
      .catch(error => console.error(error));
   }

  loginGuest(){
    this.usersService.loginGuest()
        .then(()=> this.goToHome())
        .catch(error => this.alertService.handleError(error));
  }

  recuperaContrasenya(){
    if (this.campEmail !== ""){
      this.usersService.restorePassword(this.campEmail)
        .then(() => this.alertService.showToast("T'hem enviat un missatge al teu correu electrònic per recuperar la contrasenya."))
        .catch(erro => this.alertService.showToast(erro.message));
    }else{
      this.alertService.showToast("El camp d'usuari ha d'estar emplenat.");
    }
  }

}
