import { Component, OnInit } from '@angular/core';
import { UsersService, Usuari } from 'src/app/services/users.service';
import { Router } from '@angular/router';
import { BackendlessService } from 'src/app/services/backendless.service';
import { AlertService } from 'src/app/services/alert.service';

@Component({
  selector: 'app-home',
  templateUrl: './home.page.html',
  styleUrls: ['./home.page.scss'],
})
export class HomePage implements OnInit {
  loggedUser: Backendless.User = new Usuari();
  xarxes: any[];
  esdelaDirectiva:boolean = false;
  listPatrocinadors: any[];
  slideOpts = {
    initialSlide: 0,
    speed: 400,
    loop: true
  };

  constructor(private userService: UsersService,
    private router: Router,
    private backendless: BackendlessService,
    private alertService: AlertService,
    ) {
    this.getSocial();
    this.fetchPatrocinadors();
  }

  fetchPatrocinadors() {
    console.log("fetching elements from patrocinadors");
    this.backendless.fetch("patrocinadors")
      .then(response => {
        console.log(response);
        this.listPatrocinadors = response;
      })
      .catch(responseError => {
        this.alertService.handleError(responseError);
      });
  }

  ngOnInit() {
    this.userService.isValidLogin()
      .then((result) => {
        console.log("isValidLogin result: ", result)
        this.getCurrentUser();
        this.hasRole("Directiva");
      })
      .catch(err => console.error(err));
  }

  private getCurrentUser() {
    this.userService.getCurrentUser()
      .then(user => { console.log("User: ",user); this.loggedUser = user });
  }

  logout() {
    this.userService.logOut()
      .then(() => this.router.navigateByUrl("/"));
  }


  getSocial() {
    let qb = Backendless.DataQueryBuilder.create().setWhereClause("nom='facebook' OR nom='twitter'");
    this.backendless.getXarxes(qb)
      .then(resp => {
        console.log(resp[0]);
        this.xarxes = resp;
      })
      .catch(err => this.alertService.handleError(err))
  }

  hasRole(rol: string) {
    this.userService.getUserRoles()
      .then(rolearray => {
        rolearray.forEach((val, i) => {
          if (val.toLowerCase() === rol.toLowerCase()) {
            this.esdelaDirectiva = true;
          }
        })
      });
  }
}
