import { Component, OnInit } from '@angular/core';
import { BackendlessService } from 'src/app/services/backendless.service';
import { AlertService } from 'src/app/services/alert.service';
import { Usuari, UsersService } from 'src/app/services/users.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-manteniment',
  templateUrl: './manteniment.page.html',
  styleUrls: ['./manteniment.page.scss'],
})
export class MantenimentPage implements OnInit {

  loggedUser: Usuari;
  nom: string;
  llinatge1: string;
  llinatge2: string;
  esdelaDirectiva: Boolean = false;

  constructor(
    private alertService: AlertService,
    private userservice: UsersService,
    private router: Router) {
    this.loggedUser = new Usuari();

    this.userservice.getCurrentUser()
      .then(user => {
        this.loggedUser = user as Usuari; //Recordar que la classe Usuari exten de Backendless.User.
        if (user) {
          this.llinatge1 = this.loggedUser.llinatge1;
          this.llinatge2 = this.loggedUser.llinatge2;
          this.nom = this.loggedUser.name;
        }
      });
  }

  ngOnInit() {
    this.hasRole("Directiva");
  }

  logout() {
    this.userservice.logOut()
      .then(() => this.router.navigateByUrl("auth/login"))
      .catch(err => console.error(err));
  }

  reestablirContrasenya() {
    this.userservice.restorePassword(this.loggedUser.email)
      .then(() => this.alertService.showToast("T'hem enviat un missatge al teu correu electrònic per recuperar la contrasenya."))
      .catch(erro => this.alertService.handleError(erro));
  }

  hasRole(rol: string) {
    this.userservice.getUserRoles()
      .then(rolearray => {
        rolearray.forEach((val, i) => {
          if (val.toLowerCase() === rol.toLowerCase()) {
            this.esdelaDirectiva = true;
          }
        })
      });
  }

  actualitzaUsuari(form: any) {
    console.log("form usuari: ", form);
    this.loggedUser.llinatge1 = form.form.value.llinatge1
    this.loggedUser.llinatge2 = form.form.value.llinatge2;
    this.loggedUser.name = form.form.value.nom;
    this.userservice.updateUser(this.loggedUser)
      .then(() => this.alertService.showToast("Usuari modificat correctament"))
      .catch(err => this.alertService.handleError(err));

  }


}
