import { Component, OnInit, ViewChild } from '@angular/core';
import { BackendlessService } from 'src/app/services/backendless.service';
import { AlertService } from 'src/app/services/alert.service';

@Component({
  selector: 'app-patrocinadors',
  templateUrl: './patrocinadors.page.html',
  styleUrls: ['./patrocinadors.page.scss'],
})
export class PatrocinadorsPage implements OnInit {

  listPatrocinadors: any[];
  tipusElements: string;
  nomPatrocinador: string;
  urlWeb: string;
  urlImatge: string;
  objectId: string;
  botonsAlert: any[];
  configAlert: any;

  constructor(private backendless: BackendlessService, private alertService: AlertService) {
    this.tipusElements = "patrocinadors";
    this.fetchPatrocinadors();
    this.initFormInputs();
    this.botonsAlert = [{ text: 'Entés', role: 'ok' }];
    this.configAlert = {
      header: "Patrocinador Registrat",
      message: "Patrocinador registrat correctament",
      buttons: this.botonsAlert
    };
  }

  ngOnInit() {
  }

  initFormInputs() {
    this.nomPatrocinador = '';
    this.urlWeb = '';
    this.urlImatge = '';
    this.objectId = '';
  }

  registrePatrocinador(form: any) {
    console.log(form);
    //aquesta anotació és per poder afegir atributs dinàmicament.
    let objPatrocinador: { [k: string]: any } = { nom: form.form.value.nom, url: form.form.value.url, urlImatge: form.form.value.imatge };
    let msstg = this.configAlert
    let objid = form.form.value.objectId;
    if (typeof objid !== undefined) {
      console.log(objid);
      objPatrocinador.objectId = objid;
      msstg.header = "Patrocinador Modificat";
      msstg.message = "Patrocinador modificat correctament";
    }

    this.backendless.setPatrocinador(objPatrocinador)
      .then((registeredUser) => {
        this.alertService.showAlert(this.configAlert).then(missatge => missatge.present());
        this.fetchPatrocinadors();
        this.initFormInputs();
      })
      .catch((error) => { this.alertService.handleError(error) });
  }

  fetchPatrocinadors() {
    console.log("fetching elements from patrocinadors");
    this.backendless.fetch("patrocinadors")
      .then(response => {
        console.log(response);
        this.listPatrocinadors = response;
      })
      .catch(responseError => {
        this.alertService.handleError(responseError);
      });
  }

  //Aquesta funció es cridada des del component fill llista-elements
  modificar(item: any) {
    console.log(item);
    this.nomPatrocinador = item.nom;
    this.urlWeb = item.url;
    this.urlImatge = item.urlImatge;
    this.objectId = item.objectId;
  }
}
