import { Injectable } from '@angular/core';
import Backendless from 'backendless';

@Injectable({
  providedIn: 'root'
})
export class BackendlessService {
  private _response:Object[];
  private _errorMessage:any;


  constructor() { }

  private getFromBackendless(table:string) {
    return Backendless.Data.of(table);        
  }

  private setToBackendless(table:string, dataToSave:any) {
    return Backendless.Data.of(table).save(dataToSave);      
  }
  
  private deleteFromBackendless(table:string, objId:string){
    return Backendless.Data.of(table).remove({objectId:objId});
  }

  /**
   * Retorna un array amb els tipus de partit que hi ha a la BBDD
   */
  getTipusPartit(){
    return this.getFromBackendless("tipusPartit").find();
  }

  /**
   * Procediment per desar o actualitzar els tipus de partit
   * @param nomTipusPartit Nom del tipus de partit
   */
  setTipusPartit(objTipusPartit:any){
    return this.setToBackendless("tipusPartit",objTipusPartit);
  }

  deleteTipusPartit(objectid:string){
    return this.deleteFromBackendless("tipusPartit", objectid);
  }

  getPartits(){
    return this.getFromBackendless("partits").find(); 
  }

  setPartit(partit:any){
    return this.setToBackendless("partits",partit);
  }

  getCategories(){
    return this.getFromBackendless("categoria").find();
  }

  setCategories(categoria:any){
    return this.setToBackendless("categoria",categoria);
  }

  setPatrocinador(objPatrocinador:any){
    return this.setToBackendless("patrocinadors",objPatrocinador);
  }
 

  delete(objectId:string, table:string){
    console.log("Backendless service delete -- Table: "+table+" objectId:"+objectId);
    return this.deleteFromBackendless(table, objectId);
  }
  
  fetch(table:string){
    return this.getFromBackendless(table).find();
  }

  getXarxes(query){
    return this.getFromBackendless("xarxa").find(query);
  }

  setXarxa(xarxa:any){
    return this.setToBackendless("xarxa",xarxa);
  }
  
  deleteXarxa(objid:string){
    return this.deleteFromBackendless("xarxa", objid);
  }

  addRelation(tablename:string, obj:any, column:string, childArray:any[]){
    return Backendless.Data.of(tablename).addRelation(obj, column, childArray);
  }
  getPartitById(id:string){
    return Backendless.Data.of("partits").findById(id);
  }
}
